@@ -102,8 +102,22 @@ class Storage(driver.Base):
 #            logger.error("stream_write error:%s" % e)
 #            raise e
 
-#    def list_directory(self, path=None):
-#        logger.info("list_directory path:%s" % path)
+    def list_directory(self, path=None):
+        logger.info("list_directory path:%s" % path)
+        path1 = self._init_path(path)
+        
+        try:
+            files = self._jss.bucket(self._bucket).get_all_keys(headers=None, prefix=path1)
+            logger.info("list_directory files:%s" % files)
+            if len(list(files)) == 0 :
+                raise Exception('empty')
+            
+            for file in files:
+                yield file
+        except Exception as e:
+            logger.error("list_directory error:%s" % e)
+            raise exceptions.FileNotFoundError("File not found %s" % path)
+        
         
     def stream_write(self, path, fp):
         logger.info("stream_write path:%s" % path)
